@@ -20,7 +20,7 @@
 */
 
 /*
- *  $Id: g3_model.cpp,v 1.23 2004/01/25 11:07:13 cepek Exp $
+ *  $Id: g3_model.cpp,v 1.27 2004/03/24 19:27:07 cepek Exp $
  */
 
 #include <gnu_gama/g3/g3_model.h>
@@ -39,7 +39,8 @@ Model::Model()
 
   points     = new PointBase;
   active_obs = new ObservationList;
-  par_list    = new ParameterList;
+  par_list   = new ParameterList;
+  adj        = new Adj;
 
   points->set_common_data(this); 
   set(&ellipsoid, ellipsoid_wgs84);
@@ -50,9 +51,10 @@ Model::Model()
 
 Model::~Model()
 {
-  delete points;
-  delete active_obs;
-  delete par_list;
+  delete  points;
+  delete  active_obs;
+  delete  par_list;
+  delete  adj;
 }
 
 
@@ -144,9 +146,13 @@ void Model::write_xml(std::ostream& out) const
 
 void Model::update_index(Parameter& p)
 {
-  if (!p.index()) 
+  if (!p.has_index()) 
     {
-      p.set_index(++dm_cols);
+      if (p.free())
+        p.set_index(++dm_cols);
+      else
+        p.set_index(1);
+
       par_list->push_back(&p);
     }
 }
@@ -244,20 +250,21 @@ void Model::update_linearization()
 {
   if (!check_observations()) update_observations();
 
+  cerr << "- - - - - - - - - - - - - - - - - - - - - - - .\n";
+  adj_input_data = new AdjInputData;
+
   A = new SparseMatrix<>(dm_floats, dm_rows, dm_cols);
   rhs.reset(dm_rows);
   rhs_ind = 0;
 
-  // delete B;   B = new BlockDiagonal<>;
-
   for (ObservationList::iterator 
          i=active_obs->begin(), e=active_obs->end(); i!=e; ++i)
     {
       (*i)->linearization_accept(this);
     }
 
-  adj_input_data.set_mat(A);
-  adj_input_data.set_rhs(rhs);
+  adj_input_data->set_mat(A);
+  adj_input_data->set_rhs(rhs);
 
   {
     int minx=0;
@@ -282,7 +289,7 @@ void Model::update_linearization()
               }
           }
         
-        adj_input_data.set_minx(minlist);
+        adj_input_data->set_minx(minlist);
       }
   }
   
@@ -311,8 +318,10 @@ void Model::update_linearization()
           }
       }
 
-    adj_input_data.set_cov(bd);
+    adj_input_data->set_cov(bd);
   }
+    
+  adj->set(adj_input_data);
 
   return next_state_(linear_);
 }
@@ -320,13 +329,55 @@ void Model::update_linearization()
 
 void Model::update_adjustment()
 {
+  cerr << "\n************ void Model::update_adjustment()\n\n";
   if (!check_linearization()) update_linearization();
 
+  cerr << "x() = " << adj->x();
+  for (ParameterList::iterator 
+         i=par_list->begin(), e=par_list->end(); i!=e; ++i)
+    {
+      Parameter* p = *i;
+      if (int k = p->index()) p->set_correction(adj->x()(k));
+    }
+  
+
+  cerr << "\n------------ void Model::update_adjustment()\n\n";
   return next_state_(adjust_);
 }
 
 
 void Model::write_xml_adjustment_input_data(std::ostream& out)
 {
-  adj_input_data.write_xml(out);
+  if (!check_linearization()) update_linearization();
+
+  /* see also : GNU_gama::DataParser::xml_start  *
+   *            GNU_gama::DataParser::xml_end    */
+  adj_input_data->write_xml(out);
 }
+
+
+void Model::write_xml_adjustment_results(std::ostream& out)
+{
+  if (!check_adjustment()) update_adjustment();
+
+  out << 
+    "\n<!-- adjustment results  :"
+    " dn / de / du  are in millimeters -->\n\n";
+  
+  out << "<adjustment-results>\n";
+
+  for (ParameterList::iterator 
+         i=par_list->begin(), e=par_list->end(); i!=e; ++i)
+    {
+      (*i)->write_xml_init();
+    }
+  for (ParameterList::iterator 
+         i=par_list->begin(), e=par_list->end(); i!=e; ++i)
+    {
+      (*i)->write_xml(out);
+    }
+  
+  out << "\n</adjustment-results>\n";
+}
+
+
