@@ -20,7 +20,7 @@
 */
 
 /*
- *  $Id: g3_model_vector.cpp,v 1.7 2004/04/23 22:01:31 cepek Exp $
+ *  $Id: g3_model_vector.cpp,v 1.6 2004/03/26 22:34:26 cepek Exp $
  */
 
 #include <gnu_gama/g3/g3_model.h>
@@ -41,12 +41,12 @@ bool Model::revision_visit(Vector* v)
 
   active_obs->push_back(v);
 
-  update_index(from->N);
-  update_index(from->E);
-  update_index(from->U);
-  update_index(to  ->N);
-  update_index(to  ->E);
-  update_index(to  ->U);
+  update_index(from->N_);
+  update_index(from->E_);
+  update_index(from->U_);
+  update_index(to  ->N_);
+  update_index(to  ->E_);
+  update_index(to  ->U_);
 
   dm_rows += v->dimension();            // design matrix
 
