@@ -20,7 +20,7 @@
 */
 
 /*
- *  $Id: g3_point.cpp,v 1.25 2004/04/23 22:01:31 cepek Exp $
+ *  $Id: g3_point.cpp,v 1.24 2004/03/28 16:37:07 cepek Exp $
  */
 
 #include <gnu_gama/g3/g3_point.h>
@@ -34,23 +34,21 @@ using namespace GNU_gama::g3;
 
 
 Point::Point() 
-  : B(B_), L(L_), H(H_), X(X_), Y(Y_), Z(Z_)
+  : N(N_), E(E_), U(U_), height(height_), 
+    B(B_), L(L_), H(H_), X(X_), Y(Y_), Z(Z_)
 {
   set_unused();
 
   has_xyz_ = has_blh_ = has_height_ = false;
 
-  N     .set_owner(this);
-  E     .set_owner(this);
-  U     .set_owner(this);
-  height.set_owner(this);
-  geoid .set_owner(this);
-  dB    .set_owner(this);
-  dL    .set_owner(this);
+  N_.set_owner(this);
+  E_.set_owner(this);
+  U_.set_owner(this);
 }
 
 Point::Point(const Point& point)
-  : B(B_), L(L_), H(H_), X(X_), Y(Y_), Z(Z_)
+  : N(N_), E(E_), U(U_), height(height_), 
+    B(B_), L(L_), H(H_), X(X_), Y(Y_), Z(Z_)
 {
   point_copy(point);
 }
@@ -70,14 +68,9 @@ void Point::point_copy(const Point& point)
   name   = point.name;
   common = point.common;
 
-  N = point.N;
-  E = point.E;
-  U = point.U;
-
-  height = point.height;
-  geoid  = point.geoid;
-  dB     = point.dB;
-  dL     = point.dL;
+  N_ = point.N_;
+  E_ = point.E_;
+  U_ = point.U_;
 
   X_ = point.X_;
   Y_ = point.Y_;
@@ -90,119 +83,118 @@ void Point::point_copy(const Point& point)
 
 void Point::set_unused()
 {
-  N.set_unused();
-  E.set_unused();
-  U.set_unused();
+  N_.set_unused();
+  E_.set_unused();
+  U_.set_unused();
 }
 
 void Point::set_fixed_horizontal_position()
 {
-  N.set_fixed();
-  E.set_fixed();
+  N_.set_fixed();
+  E_.set_fixed();
 }
 
 void Point::set_fixed_height()
 {
-  U.set_fixed();
+  U_.set_fixed();
 }
 
 void Point::set_fixed_position()
 {
-  N.set_fixed();
-  E.set_fixed();
-  U.set_fixed();
+  N_.set_fixed();
+  E_.set_fixed();
+  U_.set_fixed();
 }
 
 void Point::set_free_horizontal_position()
 {
-  N.set_free();
-  E.set_free();
+  N_.set_free();
+  E_.set_free();
 }
 
 void Point::set_free_height()
 {
-  U.set_free();
+  U_.set_free();
 }
 
 void Point::set_free_position()
 {
-  N.set_free();
-  E.set_free();
-  U.set_free();
+  N_.set_free();
+  E_.set_free();
+  U_.set_free();
 }
 
 void Point::set_constr_horizontal_position()
 {
-  N.set_constr();
-  E.set_constr();
+  N_.set_constr();
+  E_.set_constr();
 }
 
 void Point::set_constr_height()
 {
-  U.set_constr();
+  U_.set_constr();
 }
 
 void Point::set_constr_position()
 {
-  N.set_constr();
-  E.set_constr();
-  U.set_constr();
+  N_.set_constr();
+  E_.set_constr();
+  U_.set_constr();
 }
 
 bool Point::unused() const
 {
-  return N.unused() && E.unused() && U.unused();
+  return N_.unused() && E_.unused() && U_.unused();
 }
 
 bool Point::fixed_horizontal_position() const
 {
-  return N.fixed() && E.fixed();
+  return N_.fixed() && E_.fixed();
 }
 
 bool Point::fixed_height() const
 {
-  return U.fixed();
+  return U_.fixed();
 }
 
 bool Point::fixed_position() const
 {
-  return N.fixed() && E.fixed() && U.fixed();
+  return N_.fixed() && E_.fixed() && U_.fixed();
 }
 
 bool Point::free_horizontal_position() const
 {
-  return N.free() && E.free();
+  return N_.free() && E_.free();
 }
 
 bool Point::free_height() const
 {
-  return U.free();
+  return U_.free();
 }
 
 bool Point::free_position() const
 {
-  return N.free() && E.free() && U.free();
+  return N_.free() && E_.free() && U_.free();
 }
 
 bool Point::constr_horizontal_position() const
 {
-  return N.constr() && E.constr();
+  return N_.constr() && E_.constr();
 }
 
 bool Point::constr_height() const
 {
-  return U.constr();
+  return U_.constr();
 }
 
 bool Point::constr_position() const
 {
-  return N.constr() && E.constr() && U.constr();
+  return N_.constr() && E_.constr() && U_.constr();
 }
 
 void Point::set_blh(double b, double l, double h)
 {
   has_blh_ = true;
-  has_xyz_ = false;
 
   B_.set_init_value(b);
   L_.set_init_value(l);
@@ -220,7 +212,6 @@ void Point::set_blh(double b, double l, double h)
 void Point::set_xyz(double x, double y, double z)
 {
   has_xyz_ = true;
-  has_blh_ = false;
 
   X_.set_init_value(x);
   Y_.set_init_value(y);
@@ -238,7 +229,7 @@ void Point::set_xyz(double x, double y, double z)
 void Point::set_height(double h)
 {
   has_height_ = true;
-  height.set_init_value(h);
+  height_.set_init_value(h);
 }
 
 //  R is the transformation matrix  NEU --> XYZ  (XYZ = R * NEU)
@@ -406,9 +397,9 @@ void Point::write_xml(std::ostream& ostr)
 
   ostr << "\n        </point>\n";
 
-  N.write_xml_done();
-  E.write_xml_done();
-  U.write_xml_done();
+  N_.write_xml_done();
+  E_.write_xml_done();
+  U_.write_xml_done();
 }
 
 // ----------------------------------------------------------------------
