@@ -20,7 +20,7 @@
 */
 
 /*
- *  $Id: version.cpp,v 1.17 2004/01/25 11:07:13 cepek Exp $
+ *  $Id: version.cpp,v 1.31 2004/04/07 17:43:37 cepek Exp $
  */
 
 
@@ -28,7 +28,7 @@
 
 namespace GNU_gama {
 
-const char* GNU_gama_version  = "1.7.08";
+const char* GNU_gama_version  = "1.7.09";
 
 const char* GNU_gama_compiler =
               #if   defined (__GNUC__)
@@ -62,6 +62,80 @@ const char* GNU_gama_compiler =
 
 =============================================================================
 
+1.7.09 2004-04-07
+
+    - added new attribute zenith-angle-stdev="..." in the tag
+      <points-observations /> in gama-local input XML data
+
+    - added new parameter update-constrained-coordinates="yes | no"
+      into XML tag <parameters ... /> (input data for gama-local)
+      and all related changes in network.{h|cpp} and gkfparser.{h|cpp}
+
+    - added static data member 'bool gons' in GaMaLib::Observation
+      class to enable simple selection of output format in virtual
+      functions GaMaLib::Observation::write (this is a dirty hack but
+      I want to minimize changes in old GaMaLib)
+
+      The value of Observation::gons is set in gama-local on startup
+      by GaMaLib::Network functions set_gons() and/or set_degrees()
+
+      Implicit value of Observation::gons is true
+
+    - three bugs removed by Jan Pytel (approx. coordinates and new 360
+      degrees output):
+
+         * accord.cpp 
+         * outlying_abs_terms.h 
+           reduced_observations.h (reported by Zoltan Faludi)
+
+    - a bug in "active covariance matrix" in obsdata.h
+
+         --- obsdata.h-bug	Thu Mar 18 11:57:06 2004
+         +++ obsdata.h	Thu Mar 18 11:58:08 2004
+         @@ -345,8 +345,10 @@
+                const Index i_size = observation_list.size();
+                Index active_band  = covariance_matrix.bandWidth();
+          
+         -      if (N && N-1 < active_band) 
+         -        active_band = N-1;
+         +      if (N)
+         +        {
+         +          if (N-1 < active_band) active_band = N-1;
+         +        }
+                else
+                  active_band = 0;
+ 
+    - a bug in gkfparser.cpp reported by Jan Pytel (wrong error
+      message for "bad zenith anlge")
+
+    - gama-local: support for input of angular observables in 360
+      degrees (implicitly 400 grades)
+
+    - gama-local: optional output of adjustment results in degrees
+      (grades are used implicitly)
+
+    - scripts/gama_dep.cpp (1.01): added conditional usage of option
+      '-pipe' in makefiles generated for GNU Linux platform
+
+      bc++ compiler from Kylix3 can now use the makefiles generated in
+      the project for GNU compilers
+
+
+
+1.6.01 2004-03-03      ******  stable version 1.6  ******
+
+    - CVS tag gama-1-6 moved to point to the current development branch
+
+                        cvs tag -F gama-1-6
+
+    - added observation types Dimension and XYZ ("observed" coordinates)
+
+    - added observation dimensions into Cluster::activeCov (activeCount 
+      renamed to activeObs)
+
+                            **********************  
+
+
 1.7.08 2004-01-26
 
    - visitor pattern used in description of mathematical model (model.h)
